package com.example.listtest;

import java.util.ArrayList;
import java.util.List;

import android.os.Bundle;
import android.app.ListActivity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.TextView;

public class ExpandableListActivity extends ListActivity {

	private ExpandableListAdapter listAdapter;
	private LinearLayout moreView;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		List<String> entries = new ArrayList<String>();

        for (int i = 1; i <= 101; i++) {
            entries.add("Entry " + i);
        }
        
        moreView = getMoreView();

        listAdapter = new ExpandableListAdapter(entries);
        
        getListView().addFooterView(moreView);
        
        setListAdapter(listAdapter);
	}
	
	private LinearLayout getMoreView() {
		LinearLayout moreView = (LinearLayout) getLayoutInflater().inflate(R.layout.more_row, null);

		moreView.setOnClickListener(new View.OnClickListener() {

			public void onClick(View v) {

				listAdapter.increaseLimit();
			}

		});
		return moreView;
	}

	private class ExpandableListAdapter extends BaseAdapter {

	    private List<String> entries;
	    private int limit = 20;

	    public ExpandableListAdapter(List<String> entries) {
	        this.entries = entries;
	    }

	    public void increaseLimit() {
			limit+=20;
			
			if (limit >= entries.size()) {
				getListView().removeFooterView(moreView);
			}
			
			//notify to redraw the list
			notifyDataSetChanged();
			
		}

		@Override
	    public int getCount() {
	    	if (entries.size() <= limit) {
	            return entries.size();
	        }

	        return limit;
	    }

	    @Override
	    public Object getItem(int position) {

	    	if (position >= 0 && position < limit && position < entries.size())
                return entries.get(position);

	        return null;
	    }

	    @Override
	    public long getItemId(int position) {

	        return position;
	    }

	    @Override
	    public View getView(int position, View convertView, ViewGroup parent) {
	        View view = null;
	        
	        //reuse the convertView
	        if (convertView == null) {
	            view = getLayoutInflater().inflate(R.layout.row, null);
	        } else {
	            view = convertView;
	        }
	        String entry = entries.get(position);
	        view.setTag(position);
	        
	        fillView(view, entry);

	        return view;
	    }

		private void fillView(View view, String entry) {
			TextView text = (TextView) view.findViewById(R.id.text);
			text.setText(entry);
		}
		
		


	}
	

}
